use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007005
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
Alders
Alders'
Build
BuildType
Dave
Eilam
Eilam's
Entity
Fowler
Greg
HasDescription
HasID
HasName
HasStatus
HasWebURL
Inc
Inflator
Iterator
JSONBool
LocatorSpec
MAXMIND
MAXMIND's
Mark
MaxMind
MaxMind's
Olaf
Oschwald
Oschwald's
PayPal
Project
Rolsky
Rolsky's
Str
TeamCity
TestOccurrence
Types
WebService
autarch
drolsky
goschwald
lib
mark
oalders
ua
